import QtQuick 1.1
import com.nokia.meego 1.0
import QtMultimediaKit 1.1

Page {
    id: cameraPage;

    // page properties
    property bool isSaving: false;
    property int templateIndex: -1;
    property string previewPath: "";


    // page private methods
    function processCapturedImage(preview)
    {
        console.log(camera.capturedImagePath);
        console.log("preview: " + preview);
        btnCapture.visible = false;
        btnRetake.visible = true;
        btnSave.visible = true;
        imageTemplate.opacity = 1.0;
        imageCaptured.source = preview;
        camera.visible = false;
        resetImageCapturedPosition();
    }


    function retake()
    {        
        camera.visible = true;
        imageTemplate.opacity = 0.9;
        imageCaptured.source = "";

        btnRetake.visible = false;
        btnSave.visible = false;
        btnCapture.visible = true;
    }

    function resetImageCapturedPosition()
    {
        imageCaptured.x = 0;
        imageCaptured.y = 0;
        imageCaptured.width = cameraPage.width;
        imageCaptured.height = cameraPage.height;
        imageCaptured.scale = 1.0;
        imageCaptured.rotation = 0.0;
    }

    function imageSaved()
    {
        console.log("image saved");
        isSaving = false;
        pageToolbar.y = cameraPage.height - pageToolbar.height;
    }

    // Connections
    Connections {
        target: imageManager;
        onImageSaved : imageSaved();
    }


    // page UI
    orientationLock: PageOrientation.LockLandscape;

//    Component.onCompleted: {
//        imageTemplate.opacity = 0.9;
//        if ( templateIndex >= 0 ) {
//            imageTemplate.source = "qrc:///images/templates/template"+( templateIndex + 1 ) +".png";
//        }

//        btnRetake.visible = false;
//        btnSave.visible = false;
//        btnCapture.visible = true;
//        imageCaptured.source = "";
//    }

    onVisibleChanged: {
        if (cameraPage.visible)
        {
            imageTemplate.opacity = 0.9;
            if ( templateIndex >= 0 ) {
                imageTemplate.source = "qrc:///images/templates/template"+( templateIndex + 1 ) +".png";
            }

            btnRetake.visible = false;
            btnSave.visible = false;
            btnCapture.visible = true;
            imageCaptured.source = "";
        }
    }

    Image {
        id: imageCaptured;
        cache: false;
        asynchronous: true;
        x: 0;
        y: 0;
        width: cameraPage.width;
        height: cameraPage.height;
        fillMode: Image.PreserveAspectFit;
        smooth: true;
    }

    Camera {
        id: camera;
        anchors.fill: parent;
        focus: visible;
        flashMode: Camera.FlashAuto;
        whiteBalanceMode: Camera.WhiteBalanceAuto;
        captureResolution: Qt.size(854, 480);
        onImageCaptured: {
            processCapturedImage(preview);
        }
    }

    Image {
        id: imageTemplate;
        source: "qrc:///images/templates/template1.png";
        anchors.fill: parent;
        focus: visible;
        smooth: true;
        opacity: 0.9;
    }

    Rectangle{
        id: pageToolbar;
        anchors.left: parent.left;
        x: 0;
        y: cameraPage.height - 50;
        height: 50;
        width: parent.width;
        color: "grey"
        opacity: 0.6;

        // Buttons
        ToolButton {
            // retake
            id: btnRetake;
            iconSource: "qrc:///images/retake.png";
            text: "retake";
            x: 0;
            anchors.verticalCenter: parent.verticalCenter;
            flat: true;
            onClicked: {
                retake();
            }
        }

        ToolButton {
            // save image
            id: btnSave;
            iconSource: "qrc:///images/save.png";
            text: "save";
            x: 230;
            anchors.verticalCenter: parent.verticalCenter;
            flat:true;
            onClicked: {
                pageToolbar.y = cameraPage.height;
                if ( !isSaving ) {
                    isSaving = true;
                    timer.start();
                }
            }
        }

        ToolButton {
            // select template
            id: btnSelectTemplate;
            iconSource: "qrc:///images/select_template.png";
            x: 460;
            text: "templates";
            anchors.verticalCenter: parent.verticalCenter;
            flat:true;
            onClicked: {
                console.log(camera.capturedImagePath);
                pageStack.pop();
            }
        }

        ToolButton {
            // capture
            id: btnCapture;
            iconSource: "qrc:///images/capture.png";
            x: 690;
            text: "capture";
            anchors.verticalCenter: parent.verticalCenter;
            flat: true;
            onClicked: {
                camera.captureImage();
            }
        }
    }

    PinchArea {
        id: pinchArea;
        x: 0;
        y: 0;
        pinch.target: imageCaptured;
        height: parent.height - pageToolbar.height;
        width: parent.width;
        pinch.maximumRotation: 720;
        pinch.minimumRotation: -720;
        pinch.maximumScale: 3;
        pinch.minimumScale: 0.3;
    }

    MouseArea {
        id: mouseArea;
        x: 0;
        y: 0;
        height: parent.height - pageToolbar.height;
        width: parent.width;
        drag.target: imageCaptured;
        drag.maximumX: cameraPage.width;
        drag.minimumX: 0 - cameraPage.width;
        drag.maximumY: cameraPage.height;
        drag.minimumY: 0 - cameraPage.height;
        drag.axis: Drag.XandYAxis;

        onClicked: {
            console.log("mouse area clicked");
            toggleToolbar.running = true;
        }
    }

    // timer
    Timer {
        id: timer;
        interval: 500;
        repeat: false;
        onTriggered: {
            imageManager.captureScreenAndSaveImage();
        }
    }

    // page animations
    PropertyAnimation {
        id: toggleToolbar;
        target: pageToolbar;
        property: "y";
        to: (( pageToolbar.y < cameraPage.height ) ? cameraPage.height : ( cameraPage.height - pageToolbar.height));
        duration: 300;
    }

}
