import QtQuick 1.0
import com.nokia.meego 1.0

Page {
    id: templatePage;


    // page properties and signals
    property int selectedIndex: 0;

    // page private methods
    function selectTemplate(templateIndex)
    {
        console.log("template " + templateIndex + " selected");
        highlightBackground.x = 16 + templateIndex * 212.5;
        selectedIndex = templateIndex;
        preview.source = "qrc:///images/templates/template"+(templateIndex+1)+".png";
    }

    // page setup
    Component.onCompleted: {
        selectTemplate(0);
    }

    // page UI
    orientationLock: PageOrientation.LockLandscape;

    Image {
        id: pageBackground;
        anchors.fill: parent;
        source: "qrc:///images/template_background.png";
        fillMode: Image.Stretch;
    }

    // text - "Select a Template"
    Text {
        color: "#f7f4f4";
        anchors.top: parent.top;
        anchors.topMargin: 5;
        anchors.horizontalCenter: parent.horizontalCenter;
        font.family: "Hoefler Text";
        verticalAlignment: Text.AlignVCenter;
        horizontalAlignment: Text.AlignHCenter;
        font.pointSize: 24;
        text: "Select a Template";
    }

    // scroll view - thumbnails
    Flickable {
        id: thumbScrollView;
        y: 50;
        x: 0;
        width: parent.width;
        height: (parent.height / 4);
        contentWidth: ( parent.width / 4 ) * 20;    // 20 - number of templates
        contentHeight: thumbScrollView.height;

        Image {
            id: highlightBackground;
            x: 17.25;
            y: 5;
            source: "qrc:///images/highlight.png";
            fillMode: Image.PreserveAspectFit;
            width: 184;
            height: 108;
        }

        Row {
            Repeater {
                id: repeater;
                model: 20;   // number of templates

                Rectangle {
                    width: templatePage.width / 4;
                    height: thumbScrollView.height;
                    color: "transparent";

                    Image {
                        width: parent.width - 40;       // 168 x 94
                        anchors.centerIn: parent;
                        source: "qrc:///images/templates/template"+ ( index + 1 ) +".png";
                        fillMode: Image.PreserveAspectFit;

                        MouseArea {
                            anchors.fill: parent;
                            onClicked: {                                
                                selectTemplate(index);
                            }
                        }
                    }
                }
            }
        }
    }

    // preview image
    Rectangle {
        id: previewImage;
        color: "black";
        anchors.top: thumbScrollView.bottom;
        anchors.topMargin: 35;
        anchors.horizontalCenter: parent.horizontalCenter;
        width: 500;
        height: 281;

        Image {
            id: preview;
            anchors.fill: parent;
            source: "qrc:///images/templates/template1.png"
            fillMode: Image.PreserveAspectFit;
        }
    }

    // preview image frame
    Image {
        id: previewFrame;
        anchors.top: thumbScrollView.bottom;
        anchors.topMargin: 5;
        anchors.horizontalCenter: parent.horizontalCenter;
        width:500;
        visible: false;
        source: "qrc:///images/preview_frame.png";
        fillMode: Image.PreserveAspectFit;
    }

    Image {
        id: buttonBack;
        source: "qrc:///images/button_back.png";
        anchors.left: parent.left;
        anchors.leftMargin: 20;
        anchors.bottom: parent.bottom;
        anchors.bottomMargin: 20;
        MouseArea {
            anchors.fill: parent;
            onClicked: {
                pageStack.pop();
            }
        }
    }

    Image {
        id: select;
        source: "qrc:///images/button_go.png";
        anchors.right: parent.right;
        anchors.rightMargin: 20;
        anchors.bottom: parent.bottom;
        anchors.bottomMargin: 20;
        MouseArea {
            anchors.fill: parent;
            onClicked: {
                pageStack.push(Qt.resolvedUrl("CameraPage.qml"), { templateIndex: selectedIndex });
            }
        }
    }
}
